@@ -104,6 +104,7 @@ struct Article::Private : public Shared {
     int status;
     uint hash;
     QDateTime pubDate;
+    QString title;  // Cache the title, for performance
     mutable QSharedPointer<const Enclosure> enclosure;
 };
 
@@ -168,10 +169,8 @@ Article::Private::Private(const QString &guid_, Feed *feed_, Backend::FeedStorag
     : feed(feed_)
     , guid(guid_)
     , archive(archive_)
-    , status(archive->status(guid))
-    , hash(archive->hash(guid))
-    , pubDate(QDateTime::fromTime_t(archive->pubDate(guid)))
 {
+    archive->article(guid, hash, title, status, pubDate);
 }
 
 Article::Private::Private(const ItemPtr &article, Feed *feed_, Backend::FeedStorage *archive_)
@@ -195,7 +194,7 @@ Article::Private::Private(const ItemPtr &article, Feed *feed_, Backend::FeedStor
         archive->addEntry(guid);
 
         archive->setHash(guid, hash);
-        QString title = article->title();
+        title = article->title();
         if (title.isEmpty()) {
             title = buildTitle(article->description());
         }
@@ -203,8 +202,6 @@ Article::Private::Private(const ItemPtr &article, Feed *feed_, Backend::FeedStor
         archive->setContent(guid, article->content());
         archive->setDescription(guid, article->description());
         archive->setLink(guid, article->link());
-        //archive->setComments(guid, article.comments());
-        //archive->setCommentsLink(guid, article.commentsLink().url());
         archive->setGuidIsPermaLink(guid, false);
         archive->setGuidIsHash(guid, guid.startsWith(QLatin1String("hash:")));
         const time_t datePublished = article->datePublished();
@@ -213,7 +210,7 @@ Article::Private::Private(const ItemPtr &article, Feed *feed_, Backend::FeedStor
         } else {
             pubDate = QDateTime::currentDateTime();
         }
-        archive->setPubDate(guid, pubDate.toTime_t());
+        archive->setPubDate(guid, pubDate);
         if (firstAuthor) {
             archive->setAuthorName(guid, firstAuthor->name());
             archive->setAuthorUri(guid, firstAuthor->uri());
@@ -225,12 +222,11 @@ Article::Private::Private(const ItemPtr &article, Feed *feed_, Backend::FeedStor
         }
     } else {
         // always update comments count, as it's not used for hash calculation
-        //archive->setComments(guid, article.comments());
         if (hash != archive->hash(guid)) { //article is in archive, was it modified?
             // if yes, update
-            pubDate.setTime_t(archive->pubDate(guid));
+            pubDate = archive->pubDate(guid);
             archive->setHash(guid, hash);
-            QString title = article->title();
+            title = article->title();
             if (title.isEmpty()) {
                 title = buildTitle(article->description());
             }
@@ -243,7 +239,6 @@ Article::Private::Private(const ItemPtr &article, Feed *feed_, Backend::FeedStor
                 archive->setAuthorUri(guid, firstAuthor->uri());
                 archive->setAuthorEMail(guid, firstAuthor->email());
             }
-            //archive->setCommentsLink(guid, article.commentsLink());
         }
     }
 
@@ -257,15 +252,19 @@ Article::Article() : d(new Private)
 {
 }
 
-Article::Article(const QString &guid, Feed *feed) : d(new Private(guid, feed, feed->storage()->archiveFor(feed->xmlUrl())))
+Article::Article(const QString &guid, Feed *feed, Backend::FeedStorage *archive) : d()
+{
+    if (!archive) {
+        archive = feed->storage()->archiveFor(feed->xmlUrl());
+    }
+    d = new Private(guid, feed, archive);
+}
+
+Article::Article(const Syndication::ItemPtr &article, Feed *feed) : d(new Private(article, feed, feed->storage()->archiveFor(feed->xmlUrl())))
 {
 }
 
-Article::Article(const ItemPtr &article, Feed *feed) : d(new Private(article, feed, feed->storage()->archiveFor(feed->xmlUrl())))
-{
-}
-
-Article::Article(const ItemPtr &article, Backend::FeedStorage *archive) : d(new Private(article, nullptr, archive))
+Article::Article(const Syndication::ItemPtr &article, Backend::FeedStorage *archive) : d(new Private(article, nullptr, archive))
 {
 }
 
@@ -277,7 +276,7 @@ bool Article::isNull() const
 void Article::offsetPubDate(int secs)
 {
     d->pubDate = d->pubDate.addSecs(secs);
-    d->archive->setPubDate(d->guid, d->pubDate.toTime_t());
+    d->archive->setPubDate(d->guid, d->pubDate);
 }
 
 void Article::setDeleted()
@@ -393,11 +392,7 @@ void Article::setStatus(int stat)
 
 QString Article::title() const
 {
-    QString str;
-    if (d->archive) {
-        str = d->archive->title(d->guid);
-    }
-    return str;
+    return d->title;
 }
 
 QString Article::authorName() const
@@ -493,16 +488,6 @@ QString Article::guid() const
     return d->guid;
 }
 
-QUrl Article::commentsLink() const
-{
-    return QUrl(d->archive->commentsLink(d->guid));
-}
-
-int Article::comments() const
-{
-    return d->archive->comments(d->guid);
-}
-
 bool Article::guidIsPermaLink() const
 {
     return d->archive->guidIsPermaLink(d->guid);
