@@ -42,7 +42,6 @@ class KConfig;
 class KConfigGroup;
 
 class QDomDocument;
-class QNetworkConfigurationManager;
 class QSplitter;
 
 namespace Akregator {
@@ -72,6 +71,7 @@ public:
     /** constructor
     @param part the Akregator::Part which contains this widget
     @param parent parent widget
+    @param actionManager Akregator specific implementation of ActionManager
     @param name the name of the widget (@ref QWidget )
     */
     MainWidget(Akregator::Part *part, QWidget *parent, ActionManagerImpl *actionManager, const QString &name);
@@ -196,7 +196,7 @@ public Q_SLOTS:
     void slotSetSelectedArticleUnread();
     /** marks the currently selected article as new */
     void slotSetSelectedArticleNew();
-    /** marks the currenctly selected article as read after a user-set delay */
+    /** marks the currently selected article as read after a user-set delay */
     void slotSetCurrentArticleReadDelayed();
 
     /** switches view mode to normal view */
